import {Component, ElementRef, ViewChild} from '@angular/core';
import {Observable} from 'rxjs';
import {ActivitiesService} from './activities.service';
import {animate, style, transition, trigger} from '@angular/animations';
import {ActivityModalComponent} from './activity-modal/activity-modal.component';
import {Activity, DataCardResponse} from '@nspop/gm-web-facade-api';
import {DataCardService} from '../api/data-card.service';
import {map} from 'rxjs/operators';

@Component({
  selector: 'app-activities',
  templateUrl: './activities.component.html',
  styleUrls: ['./activities.component.scss'],
  animations: [
    trigger(
      'inOutAnimation',
      [
        transition(
          ':enter',
          [
            style({ opacity: 0 }),
            animate('0.5s ease-out',
              style({opacity: 1 }))
          ]
        ),
        transition(
          ':leave',
          [
            style({ opacity: 1 })
          ]
        )
      ]
    )
  ]
})
export class ActivitiesComponent {

  public pastActivities$: Observable<Activity[]> =  this.activitiesService.pastActivities$;
  public futureActivities$: Observable<Activity[]> =  this.activitiesService.futureActivities$;
  public selectedDataCard$: Observable<DataCardResponse | undefined> = this.dataCardService.selectedDataCard$;
  public dividerPassed = false;
  @ViewChild('divider') public divider: ElementRef | undefined;
  @ViewChild('activityModal') public activityModal: ActivityModalComponent | undefined;
  @ViewChild('button') public button: HTMLButtonElement | undefined;

  constructor(private activitiesService: ActivitiesService, private dataCardService: DataCardService) {

  }
  public onScroll($event: Event): void {
    if (this.divider) {
      const container = $event.target as HTMLDivElement;
      const elementPosition = this.divider.nativeElement.offsetTop;
      const scrollPosition = container.scrollTop + container.offsetTop;
      this.dividerPassed = scrollPosition >= elementPosition;
    }
  }
}
