import { Component, OnInit } from '@angular/core';
import {PdfService} from '../pdf.service';
import {DialogService} from '../../modals/dialog/dialog.service';
import {DialogComponent} from '../../modals/dialog/dialog.component';
import {GeneratePdfDialogComponent} from '../generate-pdf-dialog/generate-pdf-dialog.component';
import {Subscription} from 'rxjs';
import {of} from 'rxjs/internal/observable/of';

enum pdfStatus {
  idle,
  generating,
  succeeded,
  cancelled,
  failed
}

enum toastStatus {
  hidden,
  display,
  hide,
}

@Component({
  selector: 'app-generate-pdf-button',
  templateUrl: './generate-pdf-button.component.html',
  styleUrls: ['./generate-pdf-button.component.scss']
})
export class GeneratePdfButtonComponent implements OnInit {

  public isFirstDownload: boolean = true;
  public toastHidden: boolean = true;

  public pdfStatus: pdfStatus = pdfStatus.idle;
  public pdfStatusEnum = pdfStatus;

  public toastStatus: toastStatus = toastStatus.hidden;
  public toastStatusEnum = toastStatus;
  private toastDisplayTimeMs = 4000;

  private pdfSubscription: Subscription = of().subscribe();

  constructor(private pdfService: PdfService,
              private dialogService: DialogService) { }

  ngOnInit(): void {
  }

  generatePdf(): void {
    this.pdfStatus = pdfStatus.generating;
    this.pdfSubscription = this.pdfService.generatePdf().subscribe((blob: Blob) => {
      this.pdfStatus = pdfStatus.succeeded;
      this.isFirstDownload = false;
      this.displayToast();
      this.pdfService.savePdf(blob);
    }, (error => {
      this.pdfStatus = pdfStatus.failed;
      this.displayToast();
      console.error(error);
    }));
  }

  openDialog(): void {
    this.dialogService
      .show(DialogComponent, {
        data: {
          header: 'Download forløbsdata',
          component: GeneratePdfDialogComponent,
          noButtonText: 'Fortryd',
          okButtonText: 'Dan pdf med forløbsdata'
        },
        width: '440'})
      .subscribe((result) => {
        if (result) {
          this.generatePdf();
        }
      });
  }

  cancelGeneratingPdf(): void {
    this.pdfStatus = pdfStatus.cancelled;
    this.displayToast();
    this.pdfSubscription.unsubscribe();
  }

  displayToast(): void {
    this.toastStatus = toastStatus.display;
    setTimeout(() => this.hideToast(), this.toastDisplayTimeMs);
  }

  hideToast(): void {
    this.toastStatus = toastStatus.hide;
    setTimeout(() => this.toastStatus = toastStatus.hidden, 1000);
  }
}
